@@ -1,4 +1,6 @@
 #include "connectiondialog.h"
+#include "ui_connectionDialog.h"
+#include "woldialog.h"
 
 connectionDialog::connectionDialog(QWidget *parent,UserSettings oldSettings) :
         QDialog(parent),
@@ -11,6 +13,8 @@ connectionDialog::connectionDialog(QWidget *parent,UserSettings oldSettings) :
     ui->ipAddressLineEdit->setText(QString(oldSettings.ipAddress()));
     ui->usernameLineEdit->setText(QString(oldSettings.username()));
     ui->passwordLineEdit->setText(QString(oldSettings.password()));
+    wolMac_i = oldSettings.wolMac();
+    wolPort_i = oldSettings.wolPort();
 }
 
 connectionDialog::~connectionDialog()
@@ -28,7 +32,10 @@ void connectionDialog::on_buttonBox_accepted()
     settings.setIpAddress(ui->ipAddressLineEdit->text());
     settings.setUsername(ui->usernameLineEdit->text());
     settings.setPassword(ui->passwordLineEdit->text());
-
+    settings.setWolMac(wolMac_i);
+    settings.setWolPort(wolPort_i);
+    qDebug() << "connectionDialog::on_buttonBox_accepted(): wolMac: " << wolMac_i;
+    qDebug() << "connectionDialog::on_buttonBox_accepted(): wolPort" << wolPort_i;
     emit(connectionSettingsUpdated(settings));
 
 }
@@ -38,3 +45,10 @@ void connectionDialog::on_buttonBox_rejected()
     qDebug() << "Connection settings rejected";
     exit(1);
 }
+
+void connectionDialog::on_wolPushButton_clicked()
+{
+    qDebug() << "WOL Pushbutton clicked";
+    wolDialog* wolDialogUI=new wolDialog(this,&wolMac_i,&wolPort_i);
+        wolDialogUI->exec();
+}
