@@ -21,13 +21,19 @@ public:
 
 signals:
     void connectionSettingsUpdated(UserSettings settings);
+    void constructWolDialog(UserSettings settings);
 
 private:
     Ui::connectionDialog *ui;
     UserSettings settings;
+    QString wolMac_i;
+    quint16 wolPort_i;
+
 private slots:
     void on_buttonBox_rejected();
     void on_buttonBox_accepted();
+    void on_wolPushButton_clicked();
+
 };
 
 #endif // CONNECTIONDIALOG_H
