@@ -19,13 +19,19 @@
 #define MUSICNOTESPIXMAPFILE ":/images/musicnotes.png"
 #define WHITEHEARTPIXMAPFILE ":/images/whiteheart.png"
 #define RADIOPIXMAPFILE ":/images/radio.png"
-#define EMPTYALBUMARTPIXMAPFILE ":/images/cd_grey.png"
+#define LARGEEMPTYALBUMARTPIXMAPFILE ":/images/cd_grey.png"
+#define SMALLEMPTYALBUMARTPIXMAPFILE ":/images/cd_grey_small.png"
 #define FOLDERPIXMAPFILE ":/images/folder.png"
 #define LIBRARYPIXMAPFILE ":/images/library.png"
-#define LOCALALBUMARTSUFFIX "/cover_480x480.jpg"
-#define SMALLLOCALALBUMARTSUFFIX "/cover_112x112.jpg"
+#define LOCALALBUMARTSUFFIX "/cover_415x415.jpg"
+#define LARGERALBUMARTSUFFIX "/cover_112x112.jpg"
+#define SMALLALBUMARTSUFFIX "/cover_50x50.jpg"
 //#define LOCALALBUMARTSUFFIX "/cover.jpg"
 
+#define ALBUMART_WIDTH 415
+//#define SMALLICON_WIDTH 60
+//#define LARGEICON_WIDTH 112
+
 Q_DECLARE_METATYPE(QVariantHash*)
 
 #endif // squeezster_ICONS_H
